#! /usr/bin/env python

from __future__ import division

import sys
import time

STAT_FIELDS = "pid comm state ppid pgrp session tty_nr tpgid flags minflt cminflt majflt cmajflt utime stime cutime cstime priority nice num_threads itrealvalue starttime vsize rss rsslim startcode endcode startstack kstkesp kstkeip signal blocked sigignore sigcatch wchan nswap cnswap exit_signal processor rt_priority policy delayacct_blkio_ticks guest_time cguest_time".split()

MB = 1024 ** 2

def get_procstat(pid):
    with open("/proc/%d/stat" % (pid,)) as fh:
        data = fh.read().strip()
    return dict(zip(STAT_FIELDS, data.split()))


def main(pids):
    sys.stdout.write("timestamp  ")
    for pid in pids:
        data = get_procstat(pid)
        sys.stdout.write("  %6s     " % (pid,))
    sys.stdout.write("\n")
    sys.stdout.flush()
    while True:
        tstamp = time.strftime("%H:%M:%S   ")
        sys.stdout.write(tstamp)
        for pid in pids:
            data = get_procstat(pid)
            mem  = (int(data['vsize']) + int(data['rss']) * 4096) / MB
            sys.stdout.write("  %6.1f        " % (mem,))
        sys.stdout.write("\n")
        sys.stdout.flush()
        time.sleep(1)


if __name__ == "__main__":
    if len(sys.argv) < 2:
        print "Usage: show_memory.py <pid> [<pid> [...]]"
        exit()

    pids = map(int, sys.argv[1:])
    main(pids)
